@@ -309,6 +309,8 @@ class Worker:
         else:
             self.connection_string = connection_string
         self.worker_name = worker_name
+        if segment_limit is not None:
+            segment_limit = int(segment_limit)
         self.segment_limit = segment_limit
         self.reader = BlobReader(self.connection_string, return_only_source)
         self.metadata_repository = MetadataRepository(self.connection_string, worker_name + "Data", True)
